@@ -6,39 +6,23 @@
 #' the euclidean distance between cluster centers, and the density between those two
 #' points.
 #'
-#' @usage
-#' infer_initial_trajectory(space, k)
-#'
 #' @param space A numeric matrix or a data frame containing the coordinates of samples.
-#' @param k The number of clusters to cluster the data into.
+#' @param k The number of clusters
 #'
 #' @return the initial trajectory obtained by this method
 #'
-#' @export
-#'
+#' @importFrom RANN nn2
 #' @importFrom TSP TSP insert_dummy solve_TSP
 #' @importFrom stats kmeans dist
-#' @importFrom dynutils calculate_distance
-#'
-#' @examples
-#' ## Generate an example dataset and visualise it
-#' dataset <- generate_dataset(num_genes = 500, num_samples = 1000, num_groups = 4)
-#' space <- reduce_dimensionality(dataset$expression, ndim = 2)
-#' draw_trajectory_plot(space, progression_group = dataset$sample_info$group_name)
-#'
-#' ## Infer a trajectory through this space
-#' init_traj <- infer_initial_trajectory(space, k = 4)
-#'
-#' ## Visualise the trajectory
-#' draw_trajectory_plot(space, path = init_traj, progression_group = dataset$sample_info$group_name)
+#' @importFrom dynutils scale_minmax add_class
 infer_initial_trajectory <- function(space, k) {
   # input checks
   check_numeric_matrix(space, "space", finite = TRUE)
   check_numeric_vector(k, "k", whole = TRUE, finite = TRUE, range = c(1, nrow(space) - 1), length = 1)
 
-  # cluster space into k clusters
-  kmeans_clust <- stats::kmeans(as.matrix(space), centers = k)
-  centers <- kmeans_clust$centers
+  # cluster space into max k clusters
+  fit <- stats::kmeans(space, k)
+  centers <- fit$centers
 
   # calculate the euclidean space between clusters
   eucl_dist <- as.matrix(stats::dist(centers))
@@ -52,10 +36,9 @@ infer_initial_trajectory <- function(space, k) {
       pct = seq(0, 1, length.out = 21)
     ) %>%
     filter(i < j)
-  pts_space <- Matrix::Matrix((1 - pts$pct) * centers[pts$i, ] + pts$pct * centers[pts$j, ], sparse = TRUE)
-  dist_to_pts <- calculate_distance(pts_space, space, method = "euclidean")
-  rownames(dist_to_pts) <- NULL # remove rownames or knn distances might not work
-  pts$dist <- rowMeans(knn_distances(as.matrix(dist_to_pts), 10, self_loops = TRUE))
+  pts_space <- (1 - pts$pct) * centers[pts$i, ] + pts$pct * centers[pts$j, ]
+
+  pts$dist <- rowMeans(RANN::nn2(space, pts_space, k = 10)$nn.dist)
   dendis <- pts %>% group_by(i, j) %>% summarise(dist = mean(dist)) %>% ungroup()
 
   density_dist <- matrix(0, nrow = k, ncol = k)
@@ -130,12 +113,12 @@ infer_trajectory <- function(
   # input checks
   check_numeric_matrix(space, "space", finite = TRUE)
 
-  if (!is.null(k)) {
-    # use a clustering and shortest path based approach to define an intiial trajectory
-    init_traj <- infer_initial_trajectory(space, k)
-  } else {
-    init_traj <- NULL
-  }
+  init_traj <-
+    if (k <= 1) {
+      NULL
+    } else {
+      infer_initial_trajectory(space, k = k)
+    }
 
   # iteratively improve this curve using principal_curve
   fit <- princurve::principal_curve(
@@ -176,6 +159,8 @@ infer_trajectory <- function(
 #'
 #' @seealso \code{\link{infer_trajectory}}
 #'
+#' @importFrom methods is
+#'
 #' @export
 #'
 #' @examples
@@ -194,7 +179,7 @@ infer_trajectory <- function(
 #'
 #' plot(traj$time, reverse_traj$time, type = "l")
 reverse_trajectory <- function(trajectory) {
-  if (! "SCORPIUS::trajectory" %in% class(trajectory))
+  if (!is(trajectory, "SCORPIUS::trajectory"))
     stop(sQuote("trajectory"), " needs to be an object returned by infer_trajectory")
   trajectory$time <- 1 - trajectory$time
   trajectory$path <- trajectory$path[rev(seq_len(nrow(trajectory$path))), , drop = FALSE]
